@@ -5,10 +5,10 @@ import (
 	"io"
 	"log"
 	"os"
-	"runtime"
 
 	"github.com/dundee/gdu/analyze"
 	"github.com/dundee/gdu/build"
+	"github.com/dundee/gdu/common"
 	"github.com/dundee/gdu/device"
 	"github.com/dundee/gdu/stdout"
 	"github.com/dundee/gdu/tui"
@@ -26,23 +26,24 @@ type RunFlags struct {
 	NoColor          bool
 	NonInteractive   bool
 	NoProgress       bool
+	NoCross          bool
 }
 
 // Run starts gdu main logic
-func Run(flags *RunFlags, args []string, istty bool, writer io.Writer, testing bool) {
+func Run(flags *RunFlags, args []string, istty bool, writer io.Writer, app common.Application, getter device.DevicesInfoGetter) error {
 	if flags.ShowVersion {
 		fmt.Fprintln(writer, "Version:\t", build.Version)
 		fmt.Fprintln(writer, "Built time:\t", build.Time)
 		fmt.Fprintln(writer, "Built user:\t", build.User)
-		return
+		return nil
 	}
 
 	var path string
-	var ui tui.CommonUI
+	var ui common.UI
 
 	f, err := os.OpenFile(flags.LogFile, os.O_RDWR|os.O_CREATE, 0644)
 	if err != nil {
-		log.Fatalf("error opening file: %v", err)
+		return fmt.Errorf("Error opening log file: %w", err)
 	}
 	defer f.Close()
 	log.SetOutput(f)
@@ -53,11 +54,6 @@ func Run(flags *RunFlags, args []string, istty bool, writer io.Writer, testing b
 		path = "."
 	}
 
-	// we are not able to analyze disk usage on Windows and Plan9
-	if runtime.GOOS == "windows" || runtime.GOOS == "plan9" {
-		flags.ShowApparentSize = true
-	}
-
 	if flags.NonInteractive || !istty {
 		ui = stdout.CreateStdoutUI(
 			writer,
@@ -66,44 +62,31 @@ func Run(flags *RunFlags, args []string, istty bool, writer io.Writer, testing b
 			flags.ShowApparentSize,
 		)
 	} else {
-		var screen tcell.Screen
-
-		if testing {
-			screen = tcell.NewSimulationScreen("UTF-8")
-		} else {
-			screen, err = tcell.NewScreen()
-			if err != nil {
-				panic(err)
-			}
-		}
-		screen.Init()
-
-		ui = tui.CreateUI(screen, !flags.NoColor, flags.ShowApparentSize)
+		ui = tui.CreateUI(app, !flags.NoColor, flags.ShowApparentSize)
 
 		if !flags.NoColor {
 			tview.Styles.TitleColor = tcell.NewRGBColor(27, 161, 227)
 		}
 	}
 
+	if flags.NoCross {
+		mounts, err := getter.GetMounts()
+		if err != nil {
+			return fmt.Errorf("Error loading mount points: %w", err)
+		}
+		paths := device.GetNestedMountpointsPaths(path, mounts)
+		flags.IgnoreDirs = append(flags.IgnoreDirs, paths...)
+	}
+
+	ui.SetIgnoreDirPaths(flags.IgnoreDirs)
+
 	if flags.ShowDisks {
-		if runtime.GOOS == "linux" {
-			ui.SetIgnoreDirPaths(flags.IgnoreDirs)
-			ui.ListDevices(device.Getter)
-		} else {
-			fmt.Fprint(writer, "Listing devices is not yet supported for this platform")
-			return
+		if err := ui.ListDevices(getter); err != nil {
+			return fmt.Errorf("Error loading mount points: %w", err)
 		}
 	} else {
-		ui.SetIgnoreDirPaths(flags.IgnoreDirs)
 		ui.AnalyzePath(path, analyze.ProcessDir, nil)
 	}
 
-	if testing {
-		return
-	}
-
-	switch u := ui.(type) {
-	case *tui.UI:
-		u.StartUILoop()
-	}
+	return ui.StartUILoop()
 }
