@@ -4,10 +4,15 @@ import "github.com/dundee/gdu/device"
 
 // DevicesInfoGetterMock is mock of DevicesInfoGetter
 type DevicesInfoGetterMock struct {
-	Devices []*device.Device
+	Devices device.Devices
 }
 
 // GetDevicesInfo returns mocked devices
-func (t DevicesInfoGetterMock) GetDevicesInfo() ([]*device.Device, error) {
+func (t DevicesInfoGetterMock) GetDevicesInfo() (device.Devices, error) {
+	return t.Devices, nil
+}
+
+// GetMounts returns all mounted filesystems from /proc/mounts
+func (t DevicesInfoGetterMock) GetMounts() (device.Devices, error) {
 	return t.Devices, nil
 }
