@@ -11,6 +11,9 @@ func CreateTestDir() func() {
 	ioutil.WriteFile("test_dir/nested/subnested/file", []byte("hello"), 0644)
 	ioutil.WriteFile("test_dir/nested/file2", []byte("go"), 0644)
 	return func() {
-		os.RemoveAll("test_dir")
+		err := os.RemoveAll("test_dir")
+		if err != nil {
+			panic(err)
+		}
 	}
 }
