@@ -46,11 +46,16 @@ func CreateStdoutUI(output io.Writer, useColors bool, showProgress bool, showApp
 	return ui
 }
 
+// StartUILoop stub
+func (ui *UI) StartUILoop() error {
+	return nil
+}
+
 // ListDevices lists mounted devices and shows their disk usage
-func (ui *UI) ListDevices(getter device.DevicesInfoGetter) {
+func (ui *UI) ListDevices(getter device.DevicesInfoGetter) error {
 	devices, err := getter.GetDevicesInfo()
 	if err != nil {
-		panic(err)
+		return err
 	}
 
 	maxDeviceNameLenght := maxInt(maxLength(
@@ -100,6 +105,8 @@ func (ui *UI) ListDevices(getter device.DevicesInfoGetter) {
 			ui.red.Sprintf("%.f%%", usedPercent),
 			device.MountPoint)
 	}
+
+	return nil
 }
 
 // AnalyzePath analyzes recursively disk usage in given path
@@ -135,9 +142,9 @@ func (ui *UI) AnalyzePath(path string, analyzer analyze.Analyzer, _ *analyze.Fil
 
 	var lineFormat string
 	if ui.useColors {
-		lineFormat = "%20s %s\n"
+		lineFormat = "%s %20s %s\n"
 	} else {
-		lineFormat = "%9s %s\n"
+		lineFormat = "%s %9s %s\n"
 	}
 
 	var size int64
@@ -152,11 +159,13 @@ func (ui *UI) AnalyzePath(path string, analyzer analyze.Analyzer, _ *analyze.Fil
 		if file.IsDir {
 			fmt.Fprintf(ui.output,
 				lineFormat,
+				string(file.Flag),
 				ui.formatSize(size),
 				ui.blue.Sprintf("/"+file.Name))
 		} else {
 			fmt.Fprintf(ui.output,
 				lineFormat,
+				string(file.Flag),
 				ui.formatSize(size),
 				file.Name)
 		}
