@@ -16,26 +16,28 @@ import (
 )
 
 const helpTextColorized = `
- [red]up, down, k, j    [white]Move cursor up/down
-[red]enter, right, l    [white]Select directory/device
-        [red]left, h    [white]Go to parent directory
-			  [red]d    [white]Delete selected file or directory
-			  [red]r    [white]Rescan current directory
-			  [red]a    [white]Toggle between showing disk usage and apparent size
-			  [red]n    [white]Sort by name (asc/desc)
-			  [red]s    [white]Sort by size (asc/desc)
-			  [red]c    [white]Sort by items (asc/desc)
+  [red]up, down, k, j    [white]Move cursor up/down
+[red]pgup, pgdn, g, G    [white]Move cursor top/bottom
+ [red]enter, right, l    [white]Select directory/device
+         [red]left, h    [white]Go to parent directory
+			   [red]d    [white]Delete selected file or directory
+			   [red]r    [white]Rescan current directory
+			   [red]a    [white]Toggle between showing disk usage and apparent size
+			   [red]n    [white]Sort by name (asc/desc)
+			   [red]s    [white]Sort by size (asc/desc)
+			   [red]c    [white]Sort by items (asc/desc)
 `
 const helpText = `
- [::b]up, down, k, j    [white:black:-]Move cursor up/down
-[::b]enter, right, l    [white:black:-]Select directory/device
-        [::b]left, h    [white:black:-]Go to parent directory
-			  [::b]d    [white:black:-]Delete selected file or directory
-			  [::b]r    [white:black:-]Rescan current directory
-			  [::b]a    [white:black:-]Toggle between showing disk usage and apparent size
-			  [::b]n    [white:black:-]Sort by name (asc/desc)
-			  [::b]s    [white:black:-]Sort by size (asc/desc)
-			  [::b]c    [white:black:-]Sort by items (asc/desc)
+  [::b]up, down, k, j    [white:black:-]Move cursor up/down
+[::b]pgup, pgdn, g, G    [white:black:-]Move cursor top/bottom
+ [::b]enter, right, l    [white:black:-]Select directory/device
+         [::b]left, h    [white:black:-]Go to parent directory
+			   [::b]d    [white:black:-]Delete selected file or directory
+			   [::b]r    [white:black:-]Rescan current directory
+			   [::b]a    [white:black:-]Toggle between showing disk usage and apparent size
+			   [::b]n    [white:black:-]Sort by name (asc/desc)
+			   [::b]s    [white:black:-]Sort by size (asc/desc)
+			   [::b]c    [white:black:-]Sort by items (asc/desc)
 `
 
 // UI struct
@@ -73,6 +75,11 @@ func CreateUI(app common.Application, useColors bool, showApparentSize bool) *UI
 		analyzer:         analyze.ProcessDir,
 	}
 
+	app.SetBeforeDrawFunc(func(screen tcell.Screen) bool {
+		screen.Clear()
+		return false
+	})
+
 	ui.app = app
 	ui.app.SetInputCapture(ui.keyPressed)
 
@@ -87,8 +94,13 @@ func CreateUI(app common.Application, useColors bool, showApparentSize bool) *UI
 	}
 
 	ui.currentDirLabel = tview.NewTextView()
+	ui.currentDirLabel.SetBackgroundColor(tcell.ColorDefault)
 
 	ui.table = tview.NewTable().SetSelectable(true, false)
+	ui.table.SetBackgroundColor(tcell.ColorDefault)
+	ui.table.SetSelectedStyle(tcell.Style{}.
+		Foreground(tcell.ColorBlack).
+		Background(tcell.ColorWhite).Bold(true))
 
 	ui.footer = tview.NewTextView().SetDynamicColors(true)
 	if ui.useColors {
@@ -108,6 +120,7 @@ func CreateUI(app common.Application, useColors bool, showApparentSize bool) *UI
 
 	ui.pages = tview.NewPages().
 		AddPage("background", grid, true, true)
+	ui.pages.SetBackgroundColor(tcell.ColorDefault)
 
 	ui.app.SetRoot(ui.pages, true)
 
@@ -131,11 +144,11 @@ func (ui *UI) ListDevices(getter device.DevicesInfoGetter) error {
 
 	var textColor, sizeColor string
 	if ui.useColors {
-		textColor = "[#3498db:black:b]"
-		sizeColor = "[#edb20a:black:b]"
+		textColor = "[#3498db:-:b]"
+		sizeColor = "[#edb20a:-:b]"
 	} else {
-		textColor = "[white:black:b]"
-		sizeColor = "[white:black:b]"
+		textColor = "[white:-:b]"
+		sizeColor = "[white:-:b]"
 	}
 
 	for i, device := range ui.devices {
@@ -159,7 +172,7 @@ func (ui *UI) AnalyzePath(path string, analyzer analyze.Analyzer, parentDir *ana
 	abspath, _ := filepath.Abs(path)
 
 	ui.progress = tview.NewTextView().SetText("Scanning...")
-	ui.progress.SetBorder(true).SetBorderPadding(2, 2, 2, 2)
+	ui.progress.SetBorder(true).SetBorderPadding(2, 2, 2, 2).SetBackgroundColor(tcell.ColorDefault)
 	ui.progress.SetTitle(" Scanning... ")
 	ui.progress.SetDynamicColors(true)
 
@@ -199,7 +212,7 @@ func (ui *UI) AnalyzePath(path string, analyzer analyze.Analyzer, parentDir *ana
 
 		ui.app.QueueUpdateDraw(func() {
 			ui.showDir()
-			ui.pages.HidePage("progress")
+			ui.pages.RemovePage("progress")
 		})
 	}()
 }
@@ -237,7 +250,7 @@ func (ui *UI) showDir() {
 
 	rowIndex := 0
 	if ui.currentDirPath != ui.topDirPath {
-		cell := tview.NewTableCell("                        [::b]/..")
+		cell := tview.NewTableCell("                         [::b]/..")
 		cell.SetReference(ui.currentDir.Parent)
 		ui.table.SetCell(0, 0, cell)
 		rowIndex++
@@ -373,13 +386,28 @@ func (ui *UI) showErr(msg string, err error) {
 func (ui *UI) deleteSelected() {
 	row, column := ui.table.GetSelection()
 	selectedFile := ui.table.GetCell(row, column).GetReference().(*analyze.File)
-	if err := ui.currentDir.RemoveFile(selectedFile); err != nil {
-		msg := "Can't delete " + selectedFile.Name
-		ui.showErr(msg, err)
-		return
-	}
-	ui.showDir()
-	ui.table.Select(min(row, ui.table.GetRowCount()-1), 0)
+
+	modal := tview.NewModal().SetText("Deleting " + selectedFile.Name + "...")
+	ui.pages.AddPage("deleting", modal, true, true)
+
+	currentDir := ui.currentDir
+
+	go func() {
+		if err := currentDir.RemoveFile(selectedFile); err != nil {
+			msg := "Can't delete " + selectedFile.Name
+			ui.app.QueueUpdateDraw(func() {
+				ui.pages.RemovePage("deleting")
+				ui.showErr(msg, err)
+			})
+			return
+		}
+
+		ui.app.QueueUpdateDraw(func() {
+			ui.pages.RemovePage("deleting")
+			ui.showDir()
+			ui.table.Select(min(row, ui.table.GetRowCount()-1), 0)
+		})
+	}()
 }
 
 func (ui *UI) keyPressed(key *tcell.EventKey) *tcell.EventKey {
@@ -389,6 +417,10 @@ func (ui *UI) keyPressed(key *tcell.EventKey) *tcell.EventKey {
 		return key
 	}
 
+	if ui.pages.HasPage("deleting") && key.Rune() != 'q' {
+		return key
+	}
+
 	if key.Rune() == 'h' || key.Key() == tcell.KeyLeft {
 		if ui.pages.HasPage("confirm") {
 			return key
@@ -492,9 +524,9 @@ func (ui *UI) setSorting(newOrder string) {
 }
 
 func (ui *UI) updateProgress(progress *analyze.CurrentProgress) {
-	color := "[white:black:b]"
+	color := "[white:-:b]"
 	if ui.useColors {
-		color = "[red:black:b]"
+		color = "[red:-:b]"
 	}
 
 	for {
@@ -508,10 +540,10 @@ func (ui *UI) updateProgress(progress *analyze.CurrentProgress) {
 			ui.progress.SetText("Total items: " +
 				color +
 				fmt.Sprint(progress.ItemCount) +
-				"[white:black:-] size: " +
+				"[white:-:-] size: " +
 				color +
 				ui.formatSize(progress.TotalSize, false) +
-				"[white:black:-]\nCurrent item: [white:black:b]" +
+				"[white:-:-]\nCurrent item: [white:-:b]" +
 				progress.CurrentItemName)
 		})
 		progress.Mutex.Unlock()
@@ -555,15 +587,15 @@ func (ui *UI) formatFileRow(item *analyze.File) string {
 	row := string(item.Flag)
 
 	if ui.useColors {
-		row += "[#e67100:black:b]"
+		row += "[#e67100:-:b]"
 	} else {
-		row += "[white:black:b]"
+		row += "[white:-:b]"
 	}
 
 	if ui.showApparentSize {
-		row += fmt.Sprintf("%25s", ui.formatSize(item.Size, false))
+		row += fmt.Sprintf("%21s", ui.formatSize(item.Size, false))
 	} else {
-		row += fmt.Sprintf("%25s", ui.formatSize(item.Usage, false))
+		row += fmt.Sprintf("%21s", ui.formatSize(item.Usage, false))
 	}
 
 	row += " ["
@@ -596,7 +628,7 @@ func (ui *UI) formatSize(size int64, reverseColor bool) string {
 			color = "[black:white:-]"
 		}
 	} else {
-		color = "[white:black:-]"
+		color = "[white:-:-]"
 	}
 
 	switch {
